import { BaseCoin, CoinFeature, KeyCurve, UnderlyingAsset } from './base';
import { AdaNetwork } from './networks';
export interface AdaConstructorOptions {
    id: string;
    fullName: string;
    name: string;
    network: AdaNetwork;
    features: CoinFeature[];
    asset: UnderlyingAsset;
    prefix?: string;
    suffix?: string;
    primaryKeyCurve: KeyCurve;
}
export declare class Ada extends BaseCoin {
    static readonly DEFAULT_FEATURES: CoinFeature[];
    readonly network: AdaNetwork;
    constructor(options: AdaConstructorOptions);
    protected disallowedFeatures(): Set<CoinFeature>;
    protected requiredFeatures(): Set<CoinFeature>;
}
/**
 * Factory function for utxo coin instances.
 *
 * @param id uuid v4
 * @param name unique identifier of the coin
 * @param fullName Complete human-readable name of the coin
 * @param network Network object for this coin
 * @param asset Asset which this coin represents. This is the same for both mainnet and testnet variants of a coin.
 * @param features? Features of this coin. Defaults to the DEFAULT_FEATURES defined in `UtxoCoin`
 * @param prefix? Optional coin prefix. Defaults to empty string
 * @param suffix? Optional coin suffix. Defaults to coin name.
 * @param primaryKeyCurve The elliptic curve for this chain/token
 */
export declare function ada(id: string, name: string, fullName: string, network: AdaNetwork, asset: UnderlyingAsset, features?: CoinFeature[], prefix?: string, suffix?: string, primaryKeyCurve?: KeyCurve): Readonly<Ada>;
//# sourceMappingURL=ada.d.ts.map