import { BaseCoin, BaseUnit, CoinFeature, KeyCurve, UnderlyingAsset } from './base';
import { UtxoNetwork } from './networks';
interface UtxoConstructorOptions {
    id: string;
    fullName: string;
    name: string;
    network: UtxoNetwork;
    features: CoinFeature[];
    asset: UnderlyingAsset;
    baseUnit: BaseUnit;
    prefix?: string;
    suffix?: string;
    primaryKeyCurve: KeyCurve;
}
export declare class UtxoCoin extends BaseCoin {
    static readonly DEFAULT_FEATURES: CoinFeature[];
    /**
     * Additional fields for utxo coins
     */
    readonly network: UtxoNetwork;
    constructor(options: UtxoConstructorOptions);
    protected disallowedFeatures(): Set<CoinFeature>;
    protected requiredFeatures(): Set<CoinFeature>;
}
/**
 * Factory function for utxo coin instances.
 *
 * @param id uuid v4 of the coin
 * @param name unique identifier of the coin
 * @param fullName Complete human-readable name of the coin
 * @param network Network object for this coin
 * @param asset Asset which this coin represents. This is the same for both mainnet and testnet variants of a coin.
 * @param features? Features of this coin. Defaults to the DEFAULT_FEATURES defined in `UtxoCoin`
 * @param prefix? Optional coin prefix. Defaults to empty string
 * @param suffix? Optional coin suffix. Defaults to coin name.
 * @param primaryKeyCurve The elliptic curve for this chain/token
 */
export declare function utxo(id: string, name: string, fullName: string, network: UtxoNetwork, asset: UnderlyingAsset, baseUnit: BaseUnit, features?: CoinFeature[], prefix?: string, suffix?: string, 
/** All UTXOs BitGo supports are SECP256K1 **/
primaryKeyCurve?: KeyCurve): Readonly<UtxoCoin>;
export declare const utxoCoins: Readonly<BaseCoin>[];
export {};
//# sourceMappingURL=utxo.d.ts.map